==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/ChatMessageMention.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "id", 
    "mentionText", 
    "mentioned"})
@JsonInclude(Include.NON_NULL)
public class ChatMessageMention implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("id")
    protected Integer id;

    @JsonProperty("mentionText")
    protected String mentionText;

    @JsonProperty("mentioned")
    protected IdentitySet mentioned;

    protected ChatMessageMention() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.chatMessageMention";
    }

    @Property(name="id")
    @JsonIgnore
    public Optional<Integer> getId() {
        return Optional.ofNullable(id);
    }

    public ChatMessageMention withId(Integer id) {
        ChatMessageMention _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.chatMessageMention");
        _x.id = id;
        return _x;
    }

    @Property(name="mentionText")
    @JsonIgnore
    public Optional<String> getMentionText() {
        return Optional.ofNullable(mentionText);
    }

    public ChatMessageMention withMentionText(String mentionText) {
        ChatMessageMention _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.chatMessageMention");
        _x.mentionText = mentionText;
        return _x;
    }

    @Property(name="mentioned")
    @JsonIgnore
    public Optional<IdentitySet> getMentioned() {
        return Optional.ofNullable(mentioned);
    }

    public ChatMessageMention withMentioned(IdentitySet mentioned) {
        ChatMessageMention _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.chatMessageMention");
        _x.mentioned = mentioned;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Integer id;
        private String mentionText;
        private IdentitySet mentioned;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(Integer id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder mentionText(String mentionText) {
            this.mentionText = mentionText;
            this.changedFields = changedFields.add("mentionText");
            return this;
        }

        public Builder mentioned(IdentitySet mentioned) {
            this.mentioned = mentioned;
            this.changedFields = changedFields.add("mentioned");
            return this;
        }

        public ChatMessageMention build() {
            ChatMessageMention _x = new ChatMessageMention();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.chatMessageMention";
            _x.id = id;
            _x.mentionText = mentionText;
            _x.mentioned = mentioned;
            return _x;
        }
    }

    private ChatMessageMention _copy() {
        ChatMessageMention _x = new ChatMessageMention();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.mentionText = mentionText;
        _x.mentioned = mentioned;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ChatMessageMention[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("mentionText=");
        b.append(this.mentionText);
        b.append(", ");
        b.append("mentioned=");
        b.append(this.mentioned);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/ChatMessageMention.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "id", 
    "mentioned", 
    "mentionText"})
@JsonInclude(Include.NON_NULL)
public class ChatMessageMention implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("id")
    protected Integer id;

    @JsonProperty("mentioned")
    protected ChatMessageMentionedIdentitySet mentioned;

    @JsonProperty("mentionText")
    protected String mentionText;

    protected ChatMessageMention() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.chatMessageMention";
    }

    @Property(name="id")
    @JsonIgnore
    public Optional<Integer> getId() {
        return Optional.ofNullable(id);
    }

    public ChatMessageMention withId(Integer id) {
        ChatMessageMention _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.chatMessageMention");
        _x.id = id;
        return _x;
    }

    @Property(name="mentioned")
    @JsonIgnore
    public Optional<ChatMessageMentionedIdentitySet> getMentioned() {
        return Optional.ofNullable(mentioned);
    }

    public ChatMessageMention withMentioned(ChatMessageMentionedIdentitySet mentioned) {
        ChatMessageMention _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.chatMessageMention");
        _x.mentioned = mentioned;
        return _x;
    }

    @Property(name="mentionText")
    @JsonIgnore
    public Optional<String> getMentionText() {
        return Optional.ofNullable(mentionText);
    }

    public ChatMessageMention withMentionText(String mentionText) {
        ChatMessageMention _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.chatMessageMention");
        _x.mentionText = mentionText;
        return _x;
    }

    public ChatMessageMention withUnmappedField(String name, Object value) {
        ChatMessageMention _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Integer id;
        private ChatMessageMentionedIdentitySet mentioned;
        private String mentionText;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(Integer id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder mentioned(ChatMessageMentionedIdentitySet mentioned) {
            this.mentioned = mentioned;
            this.changedFields = changedFields.add("mentioned");
            return this;
        }

        public Builder mentionText(String mentionText) {
            this.mentionText = mentionText;
            this.changedFields = changedFields.add("mentionText");
            return this;
        }

        public ChatMessageMention build() {
            ChatMessageMention _x = new ChatMessageMention();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.chatMessageMention";
            _x.id = id;
            _x.mentioned = mentioned;
            _x.mentionText = mentionText;
            return _x;
        }
    }

    private ChatMessageMention _copy() {
        ChatMessageMention _x = new ChatMessageMention();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.mentioned = mentioned;
        _x.mentionText = mentionText;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ChatMessageMention[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("mentioned=");
        b.append(this.mentioned);
        b.append(", ");
        b.append("mentionText=");
        b.append(this.mentionText);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
